# Jupyter Community Call 08/30

**Date:** August 30, 2022, at 7am Pacific (in your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-08-30/7:00/Jupyter%20Community%20Call))

[**Discourse**](https://discourse.jupyter.org/t/jupyter-community-calls/668)

[**Youtube**](https://youtu.be/l_Jv-_9Nv1o)

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Isabela** Shout out to the different group of people we have today! New faces or not, thanks for taking the initiative to be here.

## Agenda Items

* **Naas** Presenting Naas open source framework to create data products from notebook templates.
    * [Jupyter Naas GitHub Repo](https://github.com/jupyter-naas)
    * Three main repos: [Naas](https://github.com/jupyter-naas/naas), [awesome-notebooks](https://github.com/jupyter-naas/awesome-notebooks), and [drivers](https://github.com/jupyter-naas/drivers).
        * Future facing work can be sampled at [nass-content-engine](https://github.com/jupyter-naas/naas-content-engine). The idea is templates as widgets.
* **Linda or Bosco (Frederic as backup)** - Demonstrate new jupyterlab-git features added through the [MLH](https://mlh.io) Summer 22 program.
  > New features are already available in v0.39.0, try it with `pip install -U jupyterlab-git`
  > [Full changelog is available there](https://github.com/jupyterlab/jupyterlab-git/releases)
* **Darian**
    * [Lumino 2](https://github.com/orgs/jupyterlab/projects/4) update leading up to JupyterLab 4 and Notebook 7 ([migrating JupyterLab to Lumino 2](https://github.com/jupyterlab/jupyterlab/pull/12992))
    * Jupyter Governance update

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [The Tyranny of Structurelessness - Jo Freeman](https://www.jofreeman.com/joreen/tyranny.htm)

## Attendees 

|   Name   |           Institution     | GitHub Handle|
|----------|---------------------------|--------------|
|    Jeremy Ravenel     |         Naas    |  @jupyter-naas
| Frederic Collonval | QuantStack | @fcollonval |
| AT Darian | QuantStack | @afshin |
| David Brochart | QuantStack | @davidbrochart |
|Maxime Jublou|Naas|@Dr0p42|
| Gabriel Fouasnon | Quansight Labs | @gabalafou |
| Wayne Decatur | Upstate Medical University | @fomightez |
| Alex Bozarth | IBM | @ajbozarth |
| Eric Holscher | Read the Docs | @ericholscher |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |

Plus 8 more.